$ErrorActionPreference = "Stop"

# Install choco
Set-ExecutionPolicy Bypass -Scope Process -Force
$env:chocolateyUseWindowsCompression = 'true'
iex ((New-Object System.Net.WebClient).DownloadString('https://chocolatey.org/install.ps1'))

$env:ChocolateyInstall = Convert-Path "$((Get-Command choco).path)\..\.."
Import-Module "$env:ChocolateyInstall\helpers\chocolateyProfile.psm1"

choco config set --name="'stopOnFirstPackageFailure'" --value="'true'"

function Write-PackageInstall($package) {
  Write-Output ""
  Write-Output "----------------------------------------------"
  Write-Output "Installing $package"
  Write-Output "----------------------------------------------"
  Write-Output ""
}
function Install-ChocoPackage($package, $options) {
  Write-PackageInstall $package
  choco install -y --no-progress $package $options
  if ($LastExitCode -ne 0) {
     throw 'Error installing with Chocolatey'
  }
}

# Add letsencrypt cert
#certutil -f -addstore root C:/Users/ContainerAdministrator/AppData/Local/Temp/DST.cer
certutil –addstore -enterprise –f "Root" C:/Users/ContainerAdministrator/AppData/Local/Temp/dst-root-ca-x3.cer
# Installing Python 3
Install-ChocoPackage python3 --version=3.7.9

[Environment]::SetEnvironmentVariable("CLOUDSDK_PYTHON","C:\Python37\python.exe")

refreshenv

Write-PackageInstall pip
python -m ensurepip
python -m pip install --upgrade pip

Write-PackageInstall virtualenv
python -m pip install -q virtualenv==20.0.25

Write-PackageInstall pyOpenSSL
python -m pip install -q pyOpenSSL==19.1.0

# Installing Git
$GIT_VERSION = "2.27.0"
Install-ChocoPackage  -package git -options --version=$GIT_VERSION
Update-SessionEnvironment

# Google Cloud SDK
Write-PackageInstall gcloud
Expand-Archive -Path $env:Temp\GoogleCloud.zip
.\GoogleCloud\google-cloud-sdk\install.bat -q

$oldSysPath = (Get-Itemproperty -path 'hklm:\system\currentcontrolset\control\session manager\environment' -Name Path).Path
$newSysPath = $oldSysPath + ";C:\GoogleCloud\google-cloud-sdk\bin;"

Set-ItemProperty -path 'hklm:\system\currentcontrolset\control\session manager\environment' -Name Path -Value $newSysPath

# AWS CLI
$AWS_VERSION = "2.2.17"
Install-ChocoPackage -package awscli -options --version=$AWS_VERSION

# Azure CLI
$AZURE_CLI_VERSION = "2.25.0"
Install-ChocoPackage  -package azure-cli -options --version=$AZURE_CLI_VERSION

# JFrog CLI
$JFROG_VERSION = "1.53.1"
Install-ChocoPackage  -package jfrog-cli -options --version=$JFROG_VERSION

# jq
$JQ_VERSION = "1.6"
Install-ChocoPackage  -package jq -options --version=$JQ_VERSION

# Kubernetes CLI
$KUBECTL_VERSION = "1.23.1"
Install-ChocoPackage  -package kubernetes-cli -options --version=$KUBECTL_VERSION

# Helm3
$HELM3_VERSION = "3.7.1"
Install-ChocoPackage  -package kubernetes-helm -options --version=$HELM3_VERSION,-m,-force
[Environment]::SetEnvironmentVariable("HELM3_PATH", "C:\ProgramData\chocolatey\lib\kubernetes-helm.$HELM3_VERSION\tools\windows-amd64\helm.exe", [System.EnvironmentVariableTarget]::Machine)

$HELM2_VERSION = "2.16.1"
Install-ChocoPackage  -package kubernetes-helm -options --version=$HELM2_VERSION,-m,-force

# Packer
$PK_VERSION = "1.7.8"
Install-ChocoPackage  -package packer -options --version=$PK_VERSION

# Terraform
$TF_VERSION = "1.1.3"
Install-ChocoPackage  -package terraform -options --version=$TF_VERSION

# docker compose
$DOCKER_COMPOSE_VERSION = "1.29.2"
Install-ChocoPackage  -package docker-compose -options --version=$DOCKER_COMPOSE_VERSION
